@@ -7,10 +7,8 @@ import traceback
 import atexit
 
 from ._codes import ERASE_LINE, CARRIAGE_RETURN
-from ._codes import COLOR_DEFAULT_FONT, COLOR_DEFAULT_BG
 from ._codes import COLOR_DEFAULT_FONT_FG, COLOR_DEFAULT_FONT_BG
 from ._codes import RESET
-from ._codes import RESET_CODE
 from ._codes import RED, LIGHT_GRAY
 from ._codes import PROGBAR_INIT, PROGBAR_ACTIVE, PROGBAR_DONE
 from ._codes import DEFAULT_STR_INFO, DEFAULT_CHANNEL
@@ -283,9 +281,9 @@ class LeadingLineOneliner:
         """ Method that will be invoked by logger.register_progbar(...) to set up a new progbar """
 
         if limit_updates is None:
-            progbar = ProgbarUnknownLength(callback_on_update=_notify_print, str_info=str_info, style=COLOR_DEFAULT_FONT+COLOR_DEFAULT_BG)
+            progbar = ProgbarUnknownLength(callback_on_update=_notify_print, str_info=str_info, style=COLOR_DEFAULT_FONT_FG+COLOR_DEFAULT_FONT_BG)
         else:
-            progbar = ProgbarKnownLength(limit_updates=limit_updates, callback_on_update=_notify_print, str_info=str_info, style=COLOR_DEFAULT_FONT+COLOR_DEFAULT_BG)
+            progbar = ProgbarKnownLength(limit_updates=limit_updates, callback_on_update=_notify_print, str_info=str_info, style=COLOR_DEFAULT_FONT_FG+COLOR_DEFAULT_FONT_BG)
         self.progbars.append(progbar)
         self.channels.append(channel)
         self.default_channels.append(default_channel)
@@ -300,9 +298,11 @@ class LeadingLineOneliner:
             channel.on_log(progbar.parse_leading_line() + '\n\t\u2ba9 Process \'{}\' stopped due to error (see traceback below).\n'.format(progbar.str_info), default_channel)
 
         # Remove all progbars
-        self.progbars = []
+        '''self.progbars = []
         self.channels = []
-        self.default_channels = []
+        self.default_channels = []'''
+        for progbar in self.progbars:
+            progbar.stop()
 
     def get_leading_line(self):
         return self._get_leading_line()
@@ -333,7 +333,7 @@ class LeadingLineOneliner:
 
         # When any progbar is active, always append the "logbox symbol" to the end of the leading line
         if len(leading_line_active) > 0:
-            style = COLOR_DEFAULT_FONT + COLOR_DEFAULT_BG
+            style = COLOR_DEFAULT_FONT_FG + COLOR_DEFAULT_FONT_BG
             leading_line_active = style + leading_line_active + ' |\u02E1\u1d52\u1d4d\u1d47\u1d52\u02e3' + RESET
 
         return leading_line_done, leading_line_active
@@ -348,17 +348,18 @@ class LeadingLineOneliner:
 
     def _parse_leading_line_done(self, indices_progbar):
         leading_line = ''
-        style = COLOR_DEFAULT_FONT + COLOR_DEFAULT_BG
+        style = COLOR_DEFAULT_FONT_FG + COLOR_DEFAULT_FONT_BG
         newline = '\n' + RESET
-        appendix = newline + style + '\t\u2ba9 Complete, time elapsed: {}'
+        appendix = newline + style + '\t\u2ba9 {}, time elapsed: {}'
         for index_progbar in indices_progbar:
             channel, default_channel, progbar = self.channels[index_progbar], self.default_channels[index_progbar], self.progbars[index_progbar]
+            str_readiness = 'Complete' if progbar.is_complete() else 'Stopped prematurely'
             str_time_elapsed = format_time(progbar.t_stop - progbar.t_start)
             # str_leading_line = progbar.parse_leading_line() + appendix.format(progbar.str_info, str_time_elapsed)
             str_leading_line = (
                 style + progbar.parse_leading_line() +
                 # ' |\u02E1\u1d52\u1d4d\u1d47\u1d52\u02e3' +
-                appendix.format(str_time_elapsed))
+                appendix.format(str_readiness, str_time_elapsed))
             leading_line += str_leading_line + newline
             channel.on_log(str_leading_line + '\n', default_channel)
         return leading_line
@@ -453,11 +454,11 @@ def _on_exit():
     Note:
         Does not make sense to make this a method of logger. Logger will be cleaned up first (?).
         The Method would then still be executed but can not access attributes of logger anymore.
-        Thus we need to use globals anyways.
+        Thus, we need to use globals anyway.
     """
     # if exception is None:
     t_elapsed = time.time() - t_start
-    str_timer_info = ('\n\nTotal runtime: {} ' + LIGHT_GRAY + '(since logbox import)' + RESET_CODE + '\n').format(format_time(t_elapsed))
+    str_timer_info = ('\n\nTotal runtime: {} ' + LIGHT_GRAY + '(since logbox import)' + RESET + '\n').format(format_time(t_elapsed))
     sys.stdout.write(str_timer_info)
 
     # Explicitly log time to all channels
@@ -465,7 +466,7 @@ def _on_exit():
         channel.on_log(str_timer_info + ' ' + format_time(time.time()-t_start), global_default_channel)
     
     # Deactivate ANSI escape codes if necessary
-    # sys.stdout.write(RESET_CODE)
+    # sys.stdout.write(RESET)
     # time.sleep(0.1)
     deactivate_esc()
 
